<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        // dd($data->fi);

        return Validator::make($data, [
            'contact' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
            'company_name' => ['required', 'string'],
            'position' => ['requried', 'string'],
            'number' => ['required', 'string'],
            'product_category' => 'required',
            'business_category' => 'required',
            'target_market' => 'required',
            'target_category' => 'required',
            'whatsapp' => 'required_without_all:line,viber,skype,wechat',
            'line' => 'required_without_all:whatsapp,viber,skype,wechat',
            'viber' => 'required_without_all:line,whatsapp,skype,wechat',
            'skype' => 'required_without_all:line,viber,whatsapp,wechat',
            'wechat' => 'required_without_all:line,viber,skype,whatsapp',
            'company_logo' => 'required',
            'company_description' => 'required'
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name' => $data['contact'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
            'role' => 0
        ]);
    }
}
